@@ -519,6 +519,7 @@ class EjudgeSession:
             auth_data: Optional[AuthData] = None,
             base_url: str = Links.BASE_URL,
             storage_path: str = 'sessions',
+            quiet: bool = False,
     ):
         """
         Args:
@@ -529,10 +530,13 @@ class EjudgeSession:
             base_url: Ejudge URL in "scheme://host[:port]" format.
             storage_path: path to storage file for auth state.
                 Path should be relative to kks config dir or absolute.
+            quiet: If True, don't show internal (re)auth attempts. Useful for scripts.
         """
         import requests
         self._http = requests.Session()
 
+        self.quiet = quiet
+
         if auth_data is not None:
             self._auth_data = copy(auth_data)
         else:
@@ -558,7 +562,7 @@ class EjudgeSession:
         self._auth(auth_data, internal=False)
 
     def _auth(self, auth_data: Optional[AuthData] = None, internal: bool = True):
-        if internal:
+        if internal and not self.quiet:
             click.secho(
                 'Ejudge session is missing or invalid, trying to auth with saved data',
                 fg='yellow', err=True
@@ -630,6 +634,10 @@ class EjudgeSession:
     def needs_auth(url):
         return 'SID' in parse_qs(urlsplit(url).query)
 
+    @property
+    def base_url(self):
+        return self._base_url
+
     def _update_sids(self, url):
         self._sids.sid = parse_qs(urlsplit(url).query)['SID'][0]
         self._sids.ejsid = self._http.cookies['EJSID']
